from oauth2client.contrib.django_util.views import oauth2_callback, oauth2_authorize
from oauth2client.contrib.django_util import signals
from django.conf import urls
from django.contrib.auth import authenticate, login
import logging

logger = logging.getLogger('racks.auth')


def callback(request):
    def local_callback(sender, request, credentials, **kwargs):
        logger.debug("Authorize user by email %s", credentials.id_token['email'])
        user = authenticate(email=credentials.id_token['email'])
        if user:
            # It is necessary to specify backend same as defined in settings.AUTHENTICATION_BACKENDS
            # and Django DB is used as to login user, and OAuth is used to associate user to
            # Django user
            user.backend = 'racks.auth.OAuthBackend'
            login(request, user)

    signals.oauth2_authorized.connect(local_callback)
    response = oauth2_callback(request)
    return response


def authorize(request):
    redirect = oauth2_authorize(request)
    # This is a dirty hack, to add 'hd' parameter to OAuth2 redirect
    redirect['Location'] += '&hd=mirantis.com'
    # This is a second dirty hack - remove access_type=offline
    if '&access_type=offline' in redirect['Location']:
        redirect['Location'] = redirect['Location'].replace('&access_type=offline', '')
    return redirect


urlpatterns = [
    urls.url(r'oauth2callback/', callback, name="callback"),
    urls.url(r'oauth2authorize/', authorize, name="authorize")
]

urls = (urlpatterns, "google_oauth", "google_oauth")
