from django.db import models

from racks.encryption import enigma, EncryptionError


class EncryptedCharField(models.CharField):
    def __init__(self, *args, **kwargs):
        kwargs['max_length'] = 255
        super(EncryptedCharField, self).__init__(*args, **kwargs)

    def deconstruct(self):
        name, path, args, kwargs = super(EncryptedCharField, self).deconstruct()
        del kwargs['max_length']
        return name, path, args, kwargs

    def from_db_value(self, value, expression, connection, context):
        try:
            return enigma.decrypt(value)
        except EncryptionError:
            return None

    def get_prep_value(self, value):
        if value:
            return enigma.encrypt(value)
        return None

    def get_prep_lookup(self, lookup_type, value):
        if lookup_type in ('exact', 'isnull'):
            return self.get_prep_value(value)
        else:
            raise TypeError(
                'lookup type %r not supported by %s' % (lookup_type, type(self).__name__)
            )

    def formfield(self, **kwargs):
        kwargs['max_length'] = 64
        return super(EncryptedCharField, self).formfield(**kwargs)
