# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models
import racks.inventory.fields
import django.db.models.deletion
from django.conf import settings
import django.core.validators
import racks.inventory.models


class Migration(migrations.Migration):

    dependencies = [
        ('auth', '0006_require_contenttypes_0002'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='FacterLocation',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('modified', models.DateTimeField(auto_now=True)),
                ('active', models.BooleanField(default=True)),
                ('fact', models.CharField(unique=True, max_length=32)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='InventoryObject',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('modified', models.DateTimeField(auto_now=True)),
                ('active', models.BooleanField(default=True)),
                ('name', models.CharField(null=True, validators=[racks.inventory.models.validate_hostname], max_length=254, blank=True, unique=True, verbose_name=b'hostname', db_index=True)),
                ('ipmi_host', models.CharField(max_length=255, unique=True, null=True, verbose_name=b'IPMI hostname', blank=True)),
                ('ipmi_user', models.CharField(max_length=255, null=True, verbose_name=b'IPMI username', blank=True)),
                ('ipmi_password', racks.inventory.fields.EncryptedCharField(null=True, verbose_name=b'IPMI password', blank=True)),
                ('dcim_id', models.IntegerField(db_index=True, unique=True, null=True, verbose_name=b'DCIM ID', blank=True)),
                ('orphan_dcim_id', models.IntegerField(db_index=True, null=True, verbose_name=b'orphan DCIM ID', blank=True)),
                ('dcim_label', models.CharField(max_length=255, null=True, verbose_name=b'DCIM label', blank=True)),
                ('dcim_jira_issue', models.CharField(max_length=255, null=True, verbose_name=b'DCIM Jira issue', blank=True)),
                ('bugs', models.CommaSeparatedIntegerField(max_length=254, null=True, blank=True)),
                ('assigned_group', models.ForeignKey(related_name='assigned_objects', blank=True, to='auth.Group', null=True)),
                ('assigned_user', models.ForeignKey(related_name='assigned_objects', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('facter_location', models.ForeignKey(related_name='inventory_objects', blank=True, to='inventory.FacterLocation', null=True)),
            ],
            options={
                'ordering': ('-id',),
            },
        ),
        migrations.CreateModel(
            name='InventoryObjectAttribute',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('modified', models.DateTimeField(auto_now=True)),
                ('active', models.BooleanField(default=True)),
                ('name', models.CharField(max_length=254)),
                ('value', models.TextField()),
                ('object', models.ForeignKey(related_name='attributes', to='inventory.InventoryObject')),
            ],
            options={
                'ordering': ('name',),
            },
        ),
        migrations.CreateModel(
            name='InventoryObjectCredential',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('modified', models.DateTimeField(auto_now=True)),
                ('active', models.BooleanField(default=True)),
                ('name', models.CharField(max_length=255)),
                ('context', models.CharField(max_length=255)),
                ('value', models.CharField(max_length=255)),
                ('inventory_object', models.ForeignKey(related_name='inventory_objects', to='inventory.InventoryObject')),
            ],
        ),
        migrations.CreateModel(
            name='InventoryObjectLabel',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('modified', models.DateTimeField(auto_now=True)),
                ('active', models.BooleanField(default=True)),
                ('name', models.CharField(unique=True, max_length=64)),
                ('type', models.CharField(default=b'GY', max_length=2, choices=[(b'GY', b'Grey'), (b'BL', b'Blue'), (b'GN', b'Green'), (b'LB', b'Lightblue'), (b'OR', b'Orange'), (b'RD', b'Red')])),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='InventoryObjectType',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('name', models.CharField(unique=True, max_length=254)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='IPv4Network',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('modified', models.DateTimeField(auto_now=True)),
                ('active', models.BooleanField(default=True)),
                ('address', models.CharField(max_length=15)),
                ('netmask', models.CharField(max_length=15)),
                ('gateway', models.CharField(max_length=15)),
            ],
            options={
                'ordering': ('address',),
                'verbose_name': 'IPv4 Network',
            },
        ),
        migrations.CreateModel(
            name='L2Address',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('address', models.CharField(unique=True, max_length=12)),
                ('inventory_object', models.ForeignKey(related_name='l2addresses', to='inventory.InventoryObject', null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='L2Network',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('modified', models.DateTimeField(auto_now=True)),
                ('active', models.BooleanField(default=True)),
                ('name', models.CharField(max_length=254)),
                ('vlanid', models.IntegerField(verbose_name=b'VLAN ID', validators=[django.core.validators.MinValueValidator(1), django.core.validators.MaxValueValidator(4094)])),
            ],
            options={
                'verbose_name': 'VLAN',
            },
        ),
        migrations.CreateModel(
            name='Lab',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('modified', models.DateTimeField(auto_now=True)),
                ('active', models.BooleanField(default=True)),
                ('name', models.CharField(max_length=255)),
                ('bugs', models.CommaSeparatedIntegerField(max_length=254, null=True, blank=True)),
                ('assigned_group', models.ForeignKey(related_name='assigned_labs', blank=True, to='auth.Group', null=True)),
                ('assigned_user', models.ForeignKey(related_name='assigned_labs', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('inventory_objects', models.ManyToManyField(related_name='labs', to='inventory.InventoryObject', blank=True)),
                ('responsible', models.ManyToManyField(related_name='labs', to=settings.AUTH_USER_MODEL, blank=True)),
                ('vlans', models.ManyToManyField(to='inventory.L2Network', verbose_name=b'VLAN', blank=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Location',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('modified', models.DateTimeField(auto_now=True)),
                ('active', models.BooleanField(default=True)),
                ('name', models.CharField(unique=True, max_length=254)),
            ],
            options={
                'ordering': ('name',),
            },
        ),
        migrations.AddField(
            model_name='ipv4network',
            name='l2network',
            field=models.ForeignKey(related_name='ipv4_networks', on_delete=django.db.models.deletion.SET_NULL, blank=True, to='inventory.L2Network', null=True),
        ),
        migrations.AddField(
            model_name='inventoryobject',
            name='ipv4network',
            field=models.ManyToManyField(related_name='inventory_objects', verbose_name=b'IPv4 network', to='inventory.IPv4Network', blank=True),
        ),
        migrations.AddField(
            model_name='inventoryobject',
            name='l2network',
            field=models.ManyToManyField(related_name='inventory_objects', verbose_name=b'VLAN', to='inventory.L2Network', blank=True),
        ),
        migrations.AddField(
            model_name='inventoryobject',
            name='label',
            field=models.ManyToManyField(related_name='inventory_objects', to='inventory.InventoryObjectLabel', blank=True),
        ),
        migrations.AddField(
            model_name='inventoryobject',
            name='responsible',
            field=models.ManyToManyField(related_name='inventory_objects', db_index=True, to=settings.AUTH_USER_MODEL, blank=True),
        ),
        migrations.AddField(
            model_name='inventoryobject',
            name='type',
            field=models.ForeignKey(related_name='inventory_objects', verbose_name=b'inventory object type', blank=True, to='inventory.InventoryObjectType', null=True),
        ),
        migrations.AddField(
            model_name='facterlocation',
            name='location',
            field=models.ForeignKey(related_name='facts', on_delete=django.db.models.deletion.SET_NULL, blank=True, to='inventory.Location', null=True),
        ),
        migrations.AlterUniqueTogether(
            name='ipv4network',
            unique_together=set([('address', 'netmask')]),
        ),
        migrations.AlterUniqueTogether(
            name='inventoryobjectcredential',
            unique_together=set([('name', 'context', 'inventory_object')]),
        ),
        migrations.AlterUniqueTogether(
            name='inventoryobjectattribute',
            unique_together=set([('name', 'object')]),
        ),
    ]
