# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion
from datetime import date
import jsonfield.fields


def move_dcim_to_separate_model(apps, schema_editor):
    InventoryObject = apps.get_model("inventory", "InventoryObject")
    Device = apps.get_model("dcim", "Device")

    for inventory_object in InventoryObject.objects.all():
        dcim_id = inventory_object.dcim_id_old or inventory_object.orphan_dcim_id
        if dcim_id:
            try:
                device = Device.objects.get(pk=dcim_id)
                # We already have this device, so we need to select best inventory object
                if inventory_object.name:
                    old_inventory_object = device.inventoryobject
                    if old_inventory_object.name:
                        print("Failed to merge %s and %s because of conflicting DCIM_ID %s" %(
                            inventory_object.name,  old_inventory_object.name, dcim_id
                        ))
                    old_inventory_object.dcim = None
                    old_inventory_object.save()
                    inventory_object.dcim = device
            except Device.DoesNotExist:
                inventory_object.dcim = Device.objects.create(
                    pk=dcim_id,
                    label=inventory_object.dcim_label or 'INCORRECT NAME %s' % dcim_id,
                    device_type='Server',
                    install_date=date(year=1970, day=1, month=1),
                    owner=1,
                    custom_values={'2': inventory_object.dcim_jira_issue},
                )
            inventory_object.source = {'DCIM': dcim_id}
            inventory_object.save()


class Migration(migrations.Migration):

    dependencies = [
        ('inventory', '0005_auto_20160802_1619'),
        ('dcim', '0003_device'),
    ]

    operations = [
        migrations.AddField(
            model_name='inventoryobject',
            name='source',
            field=jsonfield.fields.JSONField(default={}),
        ),
        migrations.RenameField(
            model_name='inventoryobject',
            old_name='dcim_id',
            new_name='dcim_id_old',
        ),
        migrations.AddField(
            model_name='inventoryobject',
            name='dcim',
            field=models.OneToOneField(on_delete=django.db.models.deletion.SET_NULL, blank=True,
                                       verbose_name=b'DCIM', to='dcim.Device', null=True),
        ),
        migrations.RunPython(move_dcim_to_separate_model),
        migrations.RemoveField(
            model_name='inventoryobject',
            name='dcim_jira_issue',
        ),
        migrations.RemoveField(
            model_name='inventoryobject',
            name='dcim_label',
        ),
        migrations.RemoveField(
            model_name='inventoryobject',
            name='orphan_dcim_id',
        ),
        migrations.RemoveField(
            model_name='inventoryobject',
            name='dcim_id_old',
        ),
    ]
