from django.test import TestCase, Client
from django.contrib.auth.models import User, Group
from racks.inventory.models import InventoryObject
from guardian.shortcuts import assign_perm

OK, FORBIDDEN = 200, 403


class TestObjectWrapper(TestCase):

    def setUp(self):
        self.client = Client()

        self.user = User.objects.create_user(username='testuser', password='password')
        self.group = Group.objects.create(name='group')
        self.group.user_set.add(self.user)

        self.io_foreign = InventoryObject.objects.create(name='test1.com', ipmi_host='test1.com')
        self.io_access_u = InventoryObject.objects.create(name='test2.com', ipmi_host='test2.com')
        self.io_access_g = InventoryObject.objects.create(name='test3.com', ipmi_host='test3.com')
        self.io_owned = InventoryObject.objects.create(name='test4.com', ipmi_host='test4.com',
                                                       assigned_user=self.user)

        assign_perm('inventory.change_inventoryobject', self.user, self.io_access_u)
        assign_perm('inventory.view_ipmi', self.user, self.io_access_u)
        assign_perm('inventory.change_inventoryobject', self.group, self.io_access_g)

    def test_url_access(self):
        client = self.client
        client.login(username='testuser', password='password')

        def get_edit_page(obj):
            return client.get('/%d/edit' % obj.pk)

        def get_access_page(obj):
            return client.get('/%d/access' % obj.pk)

        self.assertEqual(get_edit_page(self.io_foreign).status_code, FORBIDDEN)
        self.assertEqual(get_edit_page(self.io_access_u).status_code, OK)
        self.assertEqual(get_edit_page(self.io_access_g).status_code, OK)
        self.assertEqual(get_edit_page(self.io_owned).status_code, OK)

        self.assertEqual(get_access_page(self.io_foreign).status_code, FORBIDDEN)
        self.assertEqual(get_access_page(self.io_access_u).status_code, FORBIDDEN)
        self.assertEqual(get_access_page(self.io_access_g).status_code, FORBIDDEN)
        self.assertEqual(get_access_page(self.io_owned).status_code, OK)
