from racks.inventory.forms import InventoryObjectForm
from racks.inventory.models import InventoryObject
from racks import crud


class InventoryObjectListView(crud.ListView):
    def get_queryset(self):
        filters = self.get_filters()

        return InventoryObject.objects.select_related(
            'facter_location', 'facter_location__location', 'type', 'dcim',
        ).filter(**filters).prefetch_related('labels', 'attributes').order_by('name')

    def get_filters(self):
        request = self.request

        dcim_id = request.GET.get('dcim_id')
        label = request.GET.get('label')
        assigned_user = request.GET.get('assigned_user')
        assigned_group = request.GET.get('assigned_group')

        filters = {}

        if dcim_id is not None:
            if dcim_id == 'None':
                filters['dcim_id'] = None
            else:
                filters['dcim_id'] = dcim_id

        if label is not None:
            if label == 'None':
                filters['labels'] = None
            else:
                filters['labels__name'] = label

        if assigned_user is not None:
            if assigned_user == 'None':
                filters['assigned_user'] = None
            else:
                filters['assigned_user__username'] = assigned_user

        if assigned_group is not None:
            if assigned_group == 'None':
                filters['assigned_group'] = None
            else:
                filters['assigned_group__name'] = assigned_group

        return filters


class InventoryObjectDetailView(crud.DetailView):
    template_name = 'inventory/objects/detail.html'

    def get_context_data(self, **kwargs):
        context = super(InventoryObjectDetailView, self).get_context_data(**kwargs)

        view_ipmi = self.check_perm('view_ipmi')

        obj = self.object
        context['attributes'] = self.get_attributes()
        context['history'] = obj.get_history(view_ipmi=view_ipmi)

        if view_ipmi and obj.ipmi_link:
            if obj.ipmi_user and obj.ipmi_password:
                context['ipmi_form'] = {
                    'action': obj.ipmi_link + '/cgi/login.cgi',
                    'name': obj.ipmi_user,
                    'pwd': obj.ipmi_password,
                }
            else:
                context['ipmi_link'] = obj.ipmi_link

        return context

    def get_attributes(self):
        obj = self.object
        attributes = [(attr.name, attr.html_value) for attr in obj.attributes.all()]

        if self.check_perm('view_ipmi'):
            for attr_name in ['ipmi_host', 'ipmi_user', 'ipmi_password']:
                attr = getattr(obj, attr_name, None)
                if attr is not None:
                    attributes.append((attr_name, attr))

        return sorted(attributes)


class InventoryObjectUpdateView(crud.UpdateView):
    template_name = 'inventory/objects/update_form.html'


class InventoryObjectViewSet(crud.ViewSet):
    model = InventoryObject
    change_form_class = InventoryObjectForm
    update_view = InventoryObjectUpdateView
    list_view = InventoryObjectListView
    detail_view = InventoryObjectDetailView


urlpatterns = InventoryObjectViewSet('inventory.objects').urlpatterns
