from guardian.core import ObjectPermissionChecker
from django.contrib.auth.models import AbstractUser, Group, Permission
from django.contrib.contenttypes.models import ContentType
from itertools import chain


def get_perms(user_or_group, obj):
    """
    Returns permissions for given user/group and object pair, as list of
    strings.
    """
    full_perms = False
    if isinstance(user_or_group, AbstractUser):
        user = user_or_group
        assigned_user = getattr(obj, 'assigned_user', None)
        assigned_group = getattr(obj, 'assigned_group', None)

        if assigned_user == user or assigned_group and user in assigned_group.user_set.all():
            full_perms = True
    elif isinstance(user_or_group, Group):
        group = user_or_group
        assigned_group = getattr(obj, 'assigned_group', None)
        if assigned_group == group:
            full_perms = True

    if full_perms:
        ctype = ContentType.objects.get_for_model(obj)
        perms = list(chain(*Permission.objects
                           .filter(content_type=ctype)
                           .values_list("codename")))
        return perms

    check = ObjectPermissionChecker(user_or_group)
    return check.get_perms(obj)
