from django import template
from django.utils.safestring import mark_safe
from django.contrib.auth.models import Permission

from guardian.shortcuts import get_users_with_perms, get_groups_with_perms

register = template.Library()


# used in permissions_view.html
@register.filter
def users_with_access(value):
    return get_users_with_perms(value, attach_perms=True, with_superusers=False,
                                with_group_users=False).items()


# used in permissions_view.html
@register.filter
def groups_with_access(value):
    return get_groups_with_perms(value, attach_perms=True).items()


# used in permissions_view.html
@register.filter
def format_permission(value, obj=None):
    if (obj is not None) and value.endswith(obj.__class__.__name__.lower()):
        value = value[:len(value)-len(obj._meta.object_name)-1]
    return mark_safe('<span class="label label-success">'
                     '<span class="glyphicon glyphicon-lock" aria-hidden="true"></span> '
                     '%s</span>' % value)


# used in permissions_view.html
@register.filter
def permission_caption(value):
    if not isinstance(value, Permission):
        return value
    if value.codename.endswith(value.content_type.model):
        # This is one of default (or pseudo-default) permissions, ending with lowercased model name.
        # We do not want captions like "Can change inventory object", so we abbreviate things a bit.
        if value.codename.startswith('add_'):
            return 'Create'
        elif value.codename.startswith('change_'):
            return 'Modify'
        elif value.codename.startswith('delete_'):
            return 'Delete'
        elif value.codename.startswith('manage_'):
            return 'Manage Access'
        else:
            name_len = len(value.codename)-len(value.content_type.model)-1
            return value.codename[:name_len].capitalize()
    # We have no way of shortening custom permission names, so return as-is.
    return value.name


# used in permissions_view.html
@register.filter(name='sorted')
def _sorted(value, by=None):
    if by is None:
        return sorted(value)
    return sorted(value, key=lambda item: getattr(item, by, None))
