from django.conf.urls import include, patterns, url
from django.conf import settings
from rest_framework import routers

from racks.inventory.views import api_v2

if 'racks.auth.OAuthBackend' in settings.AUTHENTICATION_BACKENDS:
    from racks.auth.views import urls as oauth2_urls
else:
    oauth2_urls = []

router = routers.DefaultRouter()
router.register(r'users', api_v2.UserViewSet)
router.register(r'objects', api_v2.InventoryObjectViewSet)
router.register(r'ipv4networks', api_v2.IPv4NetworkViewSet)


urlpatterns = patterns(
    '',
    # API v2 views
    (r'^api\/v2\/', include(router.urls)),

    # Old urls
    url(r'^account\/applications/(?P<applicationid>[0-9]+)\.html',
        'racks.security.views.application', name='security.applications.view'),
    url(r'^account\/applications\.html$', 'racks.security.views.applications',
        name='security.applications.list'),
    (r'^export\/object\/inventory\.csv',
        'racks.inventory.views.misc.export_object_inventory'),
    url(r'^reports\/basic\.html$', 'racks.reports.views.basic', name='reports.views.basic'),
    url(r'^search\.html$', 'racks.inventory.views.misc.search', name='inventory.objects.search'),

    url(r'^login/$', 'racks.security.views.login_view'),
    url(r'^logout/$', 'racks.security.views.logout_view'),
    url(r'^auth/', include(oauth2_urls)),

    url(r'^account/', include('racks.account.views')),

    url(r'^launchpad/authorize$', 'racks.launchpad.views.authorize', name='launchpad.authorize'),
    url(r'^launchpad/fetchbugs$', 'racks.launchpad.views.fetch_bugs_json'),


    # Objects
    url(r'^', include('racks.inventory.views.objects')),
    url(r'^labs/', include('racks.inventory.views.labs')),
    url(r'^labels/', include('racks.inventory.views.labels')),
    url(r'^locations/', include('racks.inventory.views.locations')),
    url(r'^ipv4networks/', include('racks.inventory.views.ipv4networks')),
    url(r'^vlans/', include('racks.inventory.views.vlans')),
    url(r'^switches/', include('racks.inventory.views.switches')),

    url(r'^jenkins_ci/', include('racks.jenkins_ci.views.instances')),
    url(r'^jenkins_nodes/', include('racks.jenkins_ci.views.nodes')),
    url(r'^jenkins_logs/', include('racks.jenkins_ci.views.logs')),
    (r'^export\/jenkins_ci\/slaves\.csv',
        'racks.jenkins_ci.views.misc.export_jenkins_slaves'),
    url(r'^reports\/jenkins\.html$', 'racks.reports.views.jenkins', name='reports.views.jenkins'),
)
